<?php
/* --------------------------------------------------------------------------*/
/*                                                                           */
/* Windows Media Posting WordPress Plugin								     */   
/* Written by Shawn Van Every <vanevery@walking-productions.com>             */
/*                                                                           */
/* Copyright (c) 2007 Shawn Van Every <vanevery@walking-productions.com>     */
/*                                                                           */
/* This program is free software; you can redistribute it and/or             */
/* modify it under the terms of the GNU General Public License               */
/* as published by the Free Software Foundation; either version 2            */
/* of the License, or (at your option) any later version.                    */
/*                                                                           */
/* See file LICENSE for further informations on licensing terms.             */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           */
/*                                                                           */
/* --------------------------------------------------------------------------*/


/*
Plugin Name: Windows Media Posting
Plugin URI: http://www.walking-productions.com/WindowsMediaPostWPP/
Description: Create Windows Media Object and Embed Tags in posts.  This plugin is very similar to the QuickTime Posting Plugin available at http://www.walking-productions.com/QuickTimePostWPP/

[WINDOWSMEDIA file width height] 
OR: 
[WINDOWSMEDIA file width height true true] 

In the last version, the first "true" is for whether or not it should autoplay and the second for whether or not the controller should be visible.  The other possibility is to say "false" for either of these arguments.

Author: Shawn Van Every
Version: 1.2b
Author URI: http://www.walking-productions.com/shawn.html

Based on embedding code here:
http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dnwmt/html/windows_media_player_advanced_scripting_for_cross_browser_functionality__jchc.asp?frame=true

<OBJECT ID="MediaPlayer" width=320 height=255 
   classid="CLSID:22D6F312-B0F6-11D0-94AB-0080C74C7E95"
   CODEBASE="http://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=6,4,5,715"
        standby="Loading Microsoft Windows Media Player components..." 
        type="application/x-oleobject">
  <PARAM NAME="AutoStart" VALUE="False">
  <PARAM NAME="FileName" VALUE="http://openvlog.mobvcasting.com/posts/attachment_1169404952_439.wmv">
  <PARAM NAME="ShowControls" VALUE="False">
  <PARAM NAME="ShowStatusBar" VALUE="False">
  <EMBED type="application/x-mplayer2" 
   pluginspage="http://www.microsoft.com/Windows/MediaPlayer/"
   SRC="http://openvlog.mobvcasting.com/posts/attachment_1169404952_439.wmv"
   name="MediaPlayer"
   width=320
   height=255
   autostart=1
   showcontrols=0>
  </EMBED>
</OBJECT> 

To Do:

Get autostart to not autostart on mac with flip4mac quicktime component
Test on PC
Update for newer versions of Windows Media
Test on Macs without flip4mac


Recent Changes Version 1.2b:
Status bar and Display parameters now set to false by default.  They can be enabled with a tag such as follows:
[WINDOWSMEDIA http://url width height autoplay_boolean controller_boolean statusbar_boolean display_boolean]
for example to show everything:
[WINDOWSMEDIA file width height true true true true] 


*/ 

$windowsmedia_stag = "[WINDOWSMEDIA ";
$windowsmedia_etag = "]";

function windowsmedia_post($the_content)
{
    GLOBAL $windowsmedia_stag, $windowsmedia_etag;

    $spos = strpos($the_content, $windowsmedia_stag);
    if ($spos !== false)
    {
        $epos = strpos($the_content, $windowsmedia_etag, $spos);
        $spose = $spos + strlen($windowsmedia_stag);
        $slen = $epos - $spose;
        $tagargs = substr($the_content, $spose, $slen);
        
        $the_args = explode(" ", $tagargs);
        
        if (sizeof($the_args) == 3)
        {
            list($file,$width,$height) = explode(" ", $tagargs);
            $tags = generate_windowsmedia_tags($file,$width,$height);
            $new_content = substr($the_content,0,$spos);
            $new_content .= $tags;
            $new_content .= substr($the_content,($epos+1));
        }
        else if (sizeof($the_args) == 5)
        {
            list($file,$width,$height,$autoplay,$controller) = explode(" ",$tagargs);
            $tags = generate_windowsmedia_tags($file,$width,$height,$autoplay,$controller);
            $new_content = substr($the_content,0,$spos);
            $new_content .= $tags;
            $new_content .= substr($the_content,($epos+1));
        }
        else if (sizeof($the_args) == 7)
        {
            list($file,$width,$height,$autoplay,$controller,$statusbar,$display) = explode(" ",$tagargs);
            $tags = generate_windowsmedia_tags($file,$width,$height,$autoplay,$controller,$statusbar,$display);
            $new_content = substr($the_content,0,$spos);
            $new_content .= $tags;
            $new_content .= substr($the_content,($epos+1));
        }
        
        if ($epos+1 < strlen($the_content))
        {
            $new_content = windowsmedia_post($new_content);
        }
        return $new_content;
    }
    else
    {
        return $the_content;
    }
}

function generate_windowsmedia_tags($file, $width, $height, $autoplay="false", $controller = "", $display = "", $statusbar = "")
{
    $script_tags = "\n<script type=\"text/javascript\">\n";
    $script_tags .= "<!--\n";
    
    $script_tags .= "var ourTags='';\n";

	$tag_line = "<OBJECT ID=\"MediaPlayer\" WIDTH=\"" . $width . "\" HEIGHT=\"" . $height . "\" CLASSID=\"CLSID:22D6F312-B0F6-11D0-94AB-0080C74C7E95\" STANDBY=\"Loading Windows Media Player\" TYPE=\"application/x-oleobject\">";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";
    
	if ($controller == "")
	{
		$controller = "true";
	}
	
	if ($statusbar == "")
	{
		$statusbar = "false";
	}
	
	if ($display == "")
	{
		$display = "false";
	}

	$tag_line = "<PARAM name=\"FileName\" VALUE=\"" . $file . "\" />";
	$tags .= $tag_line . "\n";
	$script_tags .= "ourTags+='" . $tag_line . "';\n";

	$tag_line = "<PARAM name=\"ShowDisplay\" VALUE=\"" . $display . "\" />";    
	$tags .= $tag_line . "\n";
	$script_tags .= "ourTags+='" . $tag_line . "';\n";

	$tag_line = "<PARAM name=\"ShowControls\" VALUE=\"" . $controller . "\" />";    
	$tags .= $tag_line . "\n";
	$script_tags .= "ourTags+='" . $tag_line . "';\n";
    
	$tag_line = "<PARAM name=\"ShowStatusBar\" VALUE=\"" . $statusbar . "\" />";    
	$tags .= $tag_line . "\n";
	$script_tags .= "ourTags+='" . $tag_line . "';\n";

    $tag_line = "<PARAM name=\"autostart\" VALUE=\"" . $autoplay . "\" />";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";

    $tag_line = "<EMBED TYPE=\"application/x-mplayer2\" NAME=\"MediaPlayer\" ";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";

    $controller_b = 0;
    if ($controller) { $controller_b = 1; }
    $autoplay_b = 0;
    if ($autoplay=="true") { $autoplay_b = 1; }
    $statusbar_b = 0;
    if ($statusbar=="true") { $statusbar_b = 1; }
    $display_b = 0;
    if ($display=="true") { $display_b = 1; }

	$tag_line = "SRC=\"" . $file . "\" ShowControls=\"" . $controller_b . "\" ShowStatusBar=\"" . $statusbar_b . "\" ShowDisplay=\"" . $display_b . "\"";
	$tags .= $tag_line . "\n";
	$script_tags .= "ourTags+='" . $tag_line . "';\n";
    
    $tag_line = " WIDTH=\"" . $width . "\" HEIGHT=\"" . $height . "\" autostart=\"" . $autoplay_b . "\"></EMBED>";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";

    $tag_line = "</OBJECT>";    
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";

    $script_tags .= "if (typeof writeTags == \"undefined\") { "; // This isn't tested at all
    $script_tags .= "document.write(theTags);";
    $script_tags .= "} else {";
    $script_tags .= "writeTags(ourTags);\n";
    $script_tags .= "}";
    $script_tags .= "//-->\n</script>\n";
    $script_tags .= "<noscript>\n";
    $script_tags .= $tags . "\n";
    $script_tags .= "</noscript>\n";
        
    return $script_tags;
}

function windowsmedia_post_js()
{
    $linktojs = get_bloginfo('wpurl') . "/wp-content/plugins/windowsmediapost.js";
    echo "\n<script language=\"javascript\" type=\"text/javascript\" src=\"" . $linktojs . "\"></script>\n";
}

add_filter('the_content', 'windowsmedia_post');
add_filter('the_excerpt','windowsmedia_post');
add_action('wp_head','windowsmedia_post_js');
?>